@@ -250,6 +250,7 @@ func (a *App) Template(c TemplateConfigProvider) error {
 			Concurrency:            c.Concurrency(),
 			IncludeTransitiveNeeds: c.IncludeNeeds(),
 			Set:                    c.Set(),
+			Values:                 c.Values(),
 			KubeVersion:            c.KubeVersion(),
 		}, func() {
 			ok, errs = a.template(run, c)
@@ -1537,17 +1538,18 @@ Do you really want to apply?
 				subst.Releases = rs
 
 				syncOpts := &state.SyncOpts{
-					Set:              c.Set(),
-					SkipCleanup:      c.RetainValuesFiles() || c.SkipCleanup(),
-					SkipCRDs:         c.SkipCRDs(),
-					Wait:             c.Wait(),
-					WaitForJobs:      c.WaitForJobs(),
-					ReuseValues:      c.ReuseValues(),
-					ResetValues:      c.ResetValues(),
-					PostRenderer:     c.PostRenderer(),
-					PostRendererArgs: c.PostRendererArgs(),
-					SyncArgs:         c.SyncArgs(),
-					HideNotes:        c.HideNotes(),
+					Set:                  c.Set(),
+					SkipCleanup:          c.RetainValuesFiles() || c.SkipCleanup(),
+					SkipCRDs:             c.SkipCRDs(),
+					Wait:                 c.Wait(),
+					WaitForJobs:          c.WaitForJobs(),
+					ReuseValues:          c.ReuseValues(),
+					ResetValues:          c.ResetValues(),
+					PostRenderer:         c.PostRenderer(),
+					PostRendererArgs:     c.PostRendererArgs(),
+					SkipSchemaValidation: c.SkipSchemaValidation(),
+					SyncArgs:             c.SyncArgs(),
+					HideNotes:            c.HideNotes(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), syncOpts)
 			}))
@@ -1673,6 +1675,7 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 			ResetValues:             c.ResetValues(),
 			PostRenderer:            c.PostRenderer(),
 			PostRendererArgs:        c.PostRendererArgs(),
+			SkipSchemaValidation:    c.SkipSchemaValidation(),
 			SuppressOutputLineRegex: c.SuppressOutputLineRegex(),
 		}
 
