@@ -43,6 +43,7 @@ type diffConfig struct {
 	stripTrailingCR         bool
 	interactive             bool
 	skipDiffOnInstall       bool
+	skipSchemaValidation    bool
 	reuseValues             bool
 	logger                  *zap.SugaredLogger
 }
@@ -175,6 +176,10 @@ func (a diffConfig) PostRendererArgs() []string {
 	return nil
 }
 
+func (a diffConfig) SkipSchemaValidation() bool {
+	return a.skipSchemaValidation
+}
+
 func (a diffConfig) SuppressOutputLineRegex() []string {
 	return a.suppressOutputLineRegex
 }
