@@ -1,9 +1,9 @@
 package state
 
 type EnvironmentSpec struct {
-	Values      []interface{} `yaml:"values,omitempty"`
-	Secrets     []string      `yaml:"secrets,omitempty"`
-	KubeContext string        `yaml:"kubeContext,omitempty"`
+	Values      []any    `yaml:"values,omitempty"`
+	Secrets     []string `yaml:"secrets,omitempty"`
+	KubeContext string   `yaml:"kubeContext,omitempty"`
 
 	// MissingFileHandler instructs helmfile to fail when unable to find a environment values file listed
 	// under `environments.NAME.values`.
